package enseirb.myinpulse.service;

import enseirb.myinpulse.model.Project;
import enseirb.myinpulse.model.SectionCell;
import enseirb.myinpulse.service.database.ProjectService;
import enseirb.myinpulse.service.database.SectionCellService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.web.server.ResponseStatusException;

@Service
public class EntrepreneurApiService {

    private final SectionCellService sectionCellService;
    private final ProjectService projectService;

    @Autowired
    EntrepreneurApiService(SectionCellService sectionCellService, ProjectService projectService) {
        this.sectionCellService = sectionCellService;
        this.projectService = projectService;
    }

    public void editSectionCell(Long sectionCellId, SectionCell sectionCell, String mail) {
        SectionCell editSectionCell = sectionCellService.getSectionCellById(sectionCellId);
        if (editSectionCell == null) {
            System.err.println("Trying to edit unknown section cell");
            throw new ResponseStatusException(
                    HttpStatus.NOT_FOUND, "Cette cellule de section n'existe pas");
        }
        sectionCellService.updateSectionCell(
                sectionCellId,
                sectionCell.getSectionId(),
                sectionCell.getContentSectionCell(),
                sectionCell.getModificationDate());
    }

    public void removeSectionCell(Long sectionCellId, String mail) {
        SectionCell editSectionCell = sectionCellService.getSectionCellById(sectionCellId);
        if (editSectionCell == null) {
            System.err.println("Trying to remove unknown section cell");
            throw new ResponseStatusException(
                    HttpStatus.NOT_FOUND, "Cette cellule de section n'existe pas");
        }
        sectionCellService.removeSectionCellById(sectionCellId);
    }

    public void addSectionCell(SectionCell sectionCell, String mail) {
        if (sectionCell == null) {
            System.err.println("Trying to create an empty section cell");
            throw new ResponseStatusException(
                    HttpStatus.BAD_REQUEST, "La cellule de section fournie est vide");
        }
        sectionCellService.addNewSectionCell(sectionCell);
    }

    public void requestNewProject(Project project, String mail) {
        if (project == null) {
            System.err.println("Trying to request the creation of a null project");
            throw new ResponseStatusException(HttpStatus.BAD_REQUEST, "Le projet fourni est vide");
        }
        project.setProjectStatus("PENDING");
        projectService.addNewProject(project);
    }
}
