package enseirb.myinpulse.service.database;

import enseirb.myinpulse.model.Project;
import enseirb.myinpulse.model.SectionCell;
import enseirb.myinpulse.repository.SectionCellRepository;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.web.server.ResponseStatusException;

import java.time.LocalDateTime;
import java.util.Optional;

@Service
public class SectionCellService {

    private final SectionCellRepository sectionCellRepository;

    @Autowired
    SectionCellService(SectionCellRepository sectionCellRepository) {
        this.sectionCellRepository = sectionCellRepository;
    }

    public Iterable<SectionCell> getAllSectionCells() {
        return this.sectionCellRepository.findAll();
    }

    public SectionCell getSectionCellById(Long id) {
        Optional<SectionCell> sectionCell = this.sectionCellRepository.findById(id);
        if (sectionCell.isEmpty()) {
            throw new ResponseStatusException(
                    HttpStatus.NOT_FOUND, "Cette cellule de section n'existe pas");
        }
        return sectionCell.get();
    }

    public SectionCell addNewSectionCell(SectionCell sectionCell) {
        return this.sectionCellRepository.save(sectionCell);
    }

    public void removeSectionCellById(Long id) {
        this.sectionCellRepository.deleteById(id);
    }

    public SectionCell updateSectionCell(
            Long id, Long sectionId, String contentSectionCell, LocalDateTime modificationDate) {
        Optional<SectionCell> sectionCell = this.sectionCellRepository.findById(id);
        if (sectionCell.isEmpty()) {
            throw new ResponseStatusException(
                    HttpStatus.NOT_FOUND, "Cette cellule de section n'existe pas");
        }
        if (sectionId != null) {
            sectionCell.get().setSectionId(sectionId);
        }
        if (contentSectionCell != null) {
            sectionCell.get().setContentSectionCell(contentSectionCell);
        }
        if (modificationDate != null) {
            sectionCell.get().setModificationDate(modificationDate);
        }
        return this.sectionCellRepository.save(sectionCell.get());
    }

    public Iterable<SectionCell> getSectionCellsByProject(Project project, Long sectionId) {
        return this.sectionCellRepository.findByProjectSectionCellAndSectionId(project, sectionId);
    }
}
